@@ -26,7 +26,7 @@
  * DEALINGS IN THE SOFTWARE.
  ******************************************************************************
  *
- * $Log: cgiutil.c,v $
+ * $Log$
  * Revision 1.26  2006/08/29 01:56:53  sdlime
  * Fixed buffer overflow with POSTs and huge numbers of name/value pairs. Reduced MAX_PARAMS (now MS_MAX_CGI_PARAMS) from 10,000 to 100.
  *
@@ -61,7 +61,7 @@
 #include "cgiutil.h"
 #include "map.h"
 
-MS_CVSID("$Id: cgiutil.c,v 1.26 2006/08/29 01:56:53 sdlime Exp $")
+MS_CVSID("$Id: cgiutil.c 5704 2006-08-29 01:56:53Z sdlime $")
 
 #define LF 10
 #define CR 13
