@@ -28,7 +28,7 @@
  * DEALINGS IN THE SOFTWARE.
  *****************************************************************************
  *
- * $Log: classobject.c,v $
+ * $Log$
  * Revision 1.6  2005/12/21 05:34:09  sdlime
  * Fixed small problem in msRemoveStyle where a temporary style was not being initialized after being malloc'd.
  *
@@ -47,7 +47,7 @@
 #  include "cpl_conv.h"
 #endif
 
-MS_CVSID("$Id: classobject.c,v 1.6 2005/12/21 05:34:09 sdlime Exp $")
+MS_CVSID("$Id: classobject.c 5080 2005-12-21 05:34:09Z sdlime $")
 
 /**
  * Move the style up inside the array of styles.
