@@ -26,7 +26,7 @@
  * DEALINGS IN THE SOFTWARE.
  ******************************************************************************
  *
- * $Log: mapbits.c,v $
+ * $Log$
  * Revision 1.3  2005/06/14 16:03:33  dan
  * Updated copyright date to 2005
  *
@@ -37,7 +37,7 @@
 
 #include "map.h"
 
-MS_CVSID("$Id: mapbits.c,v 1.3 2005/06/14 16:03:33 dan Exp $")
+MS_CVSID("$Id: mapbits.c 4695 2005-06-14 16:03:36Z dan $")
 
 #include <limits.h>
 
