@@ -1,5 +1,5 @@
 /**********************************************************************
- * $Id: mapcontext.c,v 1.78 2006/09/05 13:49:42 julien Exp $
+ * $Id: mapcontext.c 5893 2007-01-21 17:48:37Z dan $
  *
  * Name:     mapcontext.c
  * Project:  MapServer
@@ -29,7 +29,10 @@
  * DEALINGS IN THE SOFTWARE.
  **********************************************************************
  *
- * $Log: mapcontext.c,v $
+ * $Log$
+ * Revision 1.78.2.1  2007/01/21 17:48:37  dan
+ * Ignore MS_DELETE layers in msWriteMapContext() (bug 2011)
+ *
  * Revision 1.78  2006/09/05 13:49:42  julien
  * WMC true/false bool and use format when formatlist not avail. bug 1723,1692
  *
@@ -281,7 +284,7 @@
 
 #include "map.h"
 
-MS_CVSID("$Id: mapcontext.c,v 1.78 2006/09/05 13:49:42 julien Exp $")
+MS_CVSID("$Id: mapcontext.c 5893 2007-01-21 17:48:37Z dan $")
 
 #if defined(USE_WMS_LYR) && defined(USE_OGR)
 
@@ -1916,7 +1919,7 @@ int msWriteMapContext(mapObj *map, FILE *stream)
   /* Loop on all layer   */
   for(i=0; i<map->numlayers; i++)
   {
-      if(map->layers[i].connectiontype == MS_WMS)
+      if(map->layers[i].status != MS_DELETE && map->layers[i].connectiontype == MS_WMS)
       {
           if(map->layers[i].status == MS_OFF)
               nValue = 1;
