@@ -38,7 +38,7 @@
  * DEALINGS IN THE SOFTWARE.
  ******************************************************************************
  *
- * $Log: mapcopy.c,v $
+ * $Log$
  * Revision 1.46  2006/05/26 21:46:27  tamas
  * Moving layerObj.sameconnection and msCheckConnection() internal to the MYGIS data provider.
  *
@@ -90,7 +90,7 @@
 #include "map.h"
 #include "mapsymbol.h"
 
-MS_CVSID("$Id: mapcopy.c,v 1.46 2006/05/26 21:46:27 tamas Exp $")
+MS_CVSID("$Id: mapcopy.c 6255 2007-07-02 14:46:52Z sdlime $")
 
 #include "mapcopy.h"
 
@@ -321,6 +321,7 @@ int msCopyLabel(labelObj *dst, labelObj *src)
     MS_COPYSTELEM(offsety);
     MS_COPYSTELEM(angle);
     MS_COPYSTELEM(autoangle);
+    MS_COPYSTELEM(autofollow);
     MS_COPYSTELEM(buffer);
     MS_COPYSTELEM(antialias);
     MS_COPYSTELEM(wrap);
