@@ -33,7 +33,7 @@
  * DEALINGS IN THE SOFTWARE.
  ******************************************************************************
  *
- * $Log: mapcpl.c,v $
+ * $Log$
  * Revision 1.5  2005/10/29 02:03:43  jani
  * MS RFC 8: Pluggable External Feature Layer Providers (bug 1477).
  *
@@ -45,12 +45,12 @@
  *
  */
 
-/* $Id: mapcpl.c,v 1.5 2005/10/29 02:03:43 jani Exp $ */
+/* $Id: mapcpl.c 4959 2005-10-29 02:03:43Z jani $ */
 
 #include <assert.h>
 #include "map.h"
 
-MS_CVSID("$Id: mapcpl.c,v 1.5 2005/10/29 02:03:43 jani Exp $")
+MS_CVSID("$Id: mapcpl.c 4959 2005-10-29 02:03:43Z jani $")
 
 /* should be size of largest possible filename */
 #define MS_PATH_BUF_SIZE 2048
