@@ -26,7 +26,7 @@
  * DEALINGS IN THE SOFTWARE.
  ******************************************************************************
  *
- * $Log: mapcrypto.c,v $
+ * $Log$
  * Revision 1.4  2006/06/02 20:34:24  dan
  * REmoved msDebug() call in msReadEncryptionKeyFromFile()
  *
@@ -52,7 +52,7 @@
 
 #include "map.h"
 
-MS_CVSID("$Id: mapcrypto.c,v 1.4 2006/06/02 20:34:24 dan Exp $")
+MS_CVSID("$Id: mapcrypto.c 5483 2006-06-02 20:34:24Z dan $")
 
 
 /**********************************************************************
