@@ -26,7 +26,7 @@
  * DEALINGS IN THE SOFTWARE.
  ******************************************************************************
  *
- * $Log: mapdraw.c,v $
+ * $Log$
  * Revision 1.107  2006/08/17 04:37:17  sdlime
  * In keeping with naming conventions (like it or not) label->angle_follow becomes label->autofollow...
  *
@@ -133,7 +133,7 @@
 #include "map.h"
 #include "maptime.h"
 
-MS_CVSID("$Id: mapdraw.c,v 1.107 2006/08/17 04:37:17 sdlime Exp $")
+MS_CVSID("$Id: mapdraw.c 5602 2006-08-17 04:37:17Z sdlime $")
 
 /*
  * Functions to reset any pen (color index) values previously set. Used primarily to reset things when
