@@ -27,7 +27,10 @@
  * DEALINGS IN THE SOFTWARE.
  ******************************************************************************
  *
- * $Log: mapdrawgdal.c,v $
+ * $Log$
+ * Revision 1.48.2.1  2007/02/05 05:56:19  frank
+ * Fix support for OFFSITE for simple greyscale rasters (bug 2024).
+ *
  * Revision 1.48  2006/02/22 03:52:04  frank
  * Incorporate range coloring support for rasters (bug 1673)
  *
@@ -145,7 +148,7 @@
 #include "mapresample.h"
 #include "mapthread.h"
 
-MS_CVSID("$Id: mapdrawgdal.c,v 1.48 2006/02/22 03:52:04 frank Exp $")
+MS_CVSID("$Id: mapdrawgdal.c 5900 2007-02-05 05:56:41Z frank $")
 
 extern int InvGeoTransform( double *gt_in, double *gt_out );
 
@@ -570,9 +573,22 @@ int msDrawRasterLayerGDAL(mapObj *map, layerObj *layer, imageObj *image,
           
           for( i = 0; i < 256; i++ )
           {
+              colorObj pixel;
               GDALColorEntry sEntry;
 
-              if( truecolor )
+              pixel.red = i;
+              pixel.green = i;
+              pixel.blue = i;
+              pixel.pen = i;
+              
+              if(MS_COMPARE_COLORS(pixel, layer->offsite))
+              {
+                  sEntry.c1 = 0;
+                  sEntry.c2 = 0;
+                  sEntry.c3 = 0;
+                  sEntry.c4 = 0; /* alpha set to zero */
+              }
+              else if( truecolor )
               {
                   sEntry.c1 = i;
                   sEntry.c2 = i;
