@@ -26,7 +26,7 @@
  * DEALINGS IN THE SOFTWARE.
  ******************************************************************************
  *
- * $Log: mapgdal.c,v $
+ * $Log$
  * Revision 1.30  2005/10/31 15:58:11  frank
  * ensure TLOCK_GDAL released on error exits
  *
@@ -128,7 +128,7 @@
 #include "map.h"
 #include "mapthread.h"
 
-MS_CVSID("$Id: mapgdal.c,v 1.30 2005/10/31 15:58:11 frank Exp $")
+MS_CVSID("$Id: mapgdal.c 4968 2005-10-31 15:58:11Z frank $")
 
 #ifdef USE_GDAL
 
