@@ -26,7 +26,7 @@
  * DEALINGS IN THE SOFTWARE.
  ******************************************************************************
  *
- * $Log: mapgml.c,v $
+ * $Log$
  * Revision 1.96  2006/08/22 23:14:13  hobu
  * throw away the const qualifier of msOWSLookupMetadata when we set
  * the namespace_prefix which is not defined as constant
@@ -205,7 +205,7 @@
 #include "map.h"
 #include "maperror.h"
 
-MS_CVSID("$Id: mapgml.c,v 1.96 2006/08/22 23:14:13 hobu Exp $")
+MS_CVSID("$Id: mapgml.c 5630 2006-08-22 23:14:13Z hobu $")
 
 /* Use only mapgml.c if WMS or WFS is available */
 
