@@ -1,5 +1,5 @@
 /**********************************************************************
- * $Id: mapgraticule.c,v 1.18 2006/01/16 20:37:15 sdlime Exp $
+ * $Id: mapgraticule.c 5110 2006-01-16 20:37:15Z sdlime $
  *
  * Name:     mapgraticule.c
  * Project:  MapServer
@@ -28,7 +28,7 @@
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
  * DEALINGS IN THE SOFTWARE.
  **********************************************************************
- * $Log: mapgraticule.c,v $
+ * $Log$
  * Revision 1.18  2006/01/16 20:37:15  sdlime
  * Changed label size calls to not adjust baseline offset.
  *
@@ -78,7 +78,7 @@
 #include <assert.h>
 #include "mapproject.h"
 
-MS_CVSID("$Id: mapgraticule.c,v 1.18 2006/01/16 20:37:15 sdlime Exp $")
+MS_CVSID("$Id: mapgraticule.c 5110 2006-01-16 20:37:15Z sdlime $")
 
 /**********************************************************************************************************************
  *
