@@ -26,7 +26,7 @@
  * DEALINGS IN THE SOFTWARE.
  ******************************************************************************
  *
- * $Log: maphash.c,v $
+ * $Log$
  * Revision 1.16  2005/06/14 16:03:33  dan
  * Updated copyright date to 2005
  *
@@ -43,7 +43,7 @@
 #include "map.h"
 #include "maphash.h"
 
-MS_CVSID("$Id: maphash.c,v 1.16 2005/06/14 16:03:33 dan Exp $")
+MS_CVSID("$Id: maphash.c 4695 2005-06-14 16:03:36Z dan $")
 
 static unsigned hash(const char *key)
 {
