@@ -1,5 +1,5 @@
 /**********************************************************************
- * $Id: maphttp.c,v 1.22 2006/04/17 19:06:49 dan Exp $
+ * $Id: maphttp.c 5395 2006-04-17 19:06:49Z dan $
  *
  * Project:  MapServer
  * Purpose:  Utility functions to access files via HTTP (requires libcurl)
@@ -26,7 +26,7 @@
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
  * DEALINGS IN THE SOFTWARE.
  **********************************************************************
- * $Log: maphttp.c,v $
+ * $Log$
  * Revision 1.22  2006/04/17 19:06:49  dan
  * Set User-Agent in HTTP headers of client WMS/WFS connections (bug 1749)
  *
@@ -109,7 +109,7 @@
 #include "mapows.h"
 #include "mapthread.h"
 
-MS_CVSID("$Id: maphttp.c,v 1.22 2006/04/17 19:06:49 dan Exp $")
+MS_CVSID("$Id: maphttp.c 5395 2006-04-17 19:06:49Z dan $")
 
 #include <time.h>
 #ifndef _WIN32
