@@ -26,7 +26,7 @@
  * DEALINGS IN THE SOFTWARE.
  ******************************************************************************
  *
- * $Log: mapimagemap.c,v $
+ * $Log$
  * Revision 1.29  2006/08/29 19:34:59  frank
  * Fix C++'ism (declare values after first statement in block).
  *
@@ -78,7 +78,7 @@
 #include <io.h>
 #endif
 
-MS_CVSID("$Id: mapimagemap.c,v 1.29 2006/08/29 19:34:59 frank Exp $")
+MS_CVSID("$Id: mapimagemap.c 5713 2006-08-29 19:34:59Z frank $")
 
 #define MYDEBUG 0
 #define DEBUG_IF if (MYDEBUG > 2) 
