@@ -26,7 +26,7 @@
  * DEALINGS IN THE SOFTWARE.
  ******************************************************************************
  *
- * $Log: mapio.c,v $
+ * $Log$
  * Revision 1.16  2006/08/22 23:07:52  hobu
  * cast to a const char* the first argument to strncasecmp
  *
@@ -87,7 +87,7 @@
 #include <io.h>
 #endif
 
-MS_CVSID("$Id: mapio.c,v 1.16 2006/08/22 23:07:52 hobu Exp $")
+MS_CVSID("$Id: mapio.c 5628 2006-08-22 23:07:52Z hobu $")
 
 static int is_msIO_initialized = MS_FALSE;
 
