@@ -26,7 +26,7 @@
  * DEALINGS IN THE SOFTWARE.
  ******************************************************************************
  *
- * $Log: mapjoin.c,v $
+ * $Log$
  * Revision 1.29  2006/05/12 18:32:41  pramsey
  * Added support for postgresql joins (Bug 1570).
  *
@@ -46,7 +46,7 @@
 
 #include "map.h"
 
-MS_CVSID("$Id: mapjoin.c,v 1.29 2006/05/12 18:32:41 pramsey Exp $")
+MS_CVSID("$Id: mapjoin.c 5433 2006-05-12 18:32:41Z pramsey $")
 
 #define ROW_ALLOCATION_SIZE 10
 
