@@ -26,7 +26,7 @@
  * DEALINGS IN THE SOFTWARE.
  ******************************************************************************
  *
- * $Log: maplabel.c,v $
+ * $Log$
  * Revision 1.86  2006/09/06 05:26:18  sdlime
  * Fixed a bug with curved labels where character advance array was not being gdFree'd. (bug 1899)
  *
@@ -82,7 +82,7 @@
 
 #include "map.h"
 
-MS_CVSID("$Id: maplabel.c,v 1.86 2006/09/06 05:26:18 sdlime Exp $")
+MS_CVSID("$Id: maplabel.c 5746 2006-09-06 05:26:18Z sdlime $")
 
 int msAddLabel(mapObj *map, int layerindex, int classindex, int shapeindex, int tileindex, pointObj *point, labelPathObj *labelpath, char *string, double featuresize, labelObj *label )
 {
