@@ -26,7 +26,7 @@
  * DEALINGS IN THE SOFTWARE.
  ******************************************************************************
  *
- * $Log: maplayer.c,v $
+ * $Log$
  * Revision 1.112  2006/08/22 13:56:58  hobu
  * ssh!  comment out "tile;" which was unused and
  * causing compiler to complain
@@ -91,7 +91,7 @@
 #include "mapogcfilter.h"
 
 #include <assert.h>
-MS_CVSID("$Id: maplayer.c,v 1.112 2006/08/22 13:56:58 hobu Exp $")
+MS_CVSID("$Id: maplayer.c 5621 2006-08-22 13:56:58Z hobu $")
 
 
 static int populateVirtualTable(layerVTableObj *vtable);
