@@ -26,7 +26,7 @@
  * DEALINGS IN THE SOFTWARE.
  ******************************************************************************
  *
- * $Log: maplegend.c,v $
+ * $Log$
  * Revision 1.62  2006/08/04 04:36:12  sdlime
  * Removed cut & paste artifact (oops).
  *
@@ -83,7 +83,7 @@
 
 #include "map.h"
 
-MS_CVSID("$Id: maplegend.c,v 1.62 2006/08/04 04:36:12 sdlime Exp $")
+MS_CVSID("$Id: maplegend.c 5576 2006-08-04 04:36:12Z sdlime $")
 
 #define PSF .8
 #define VMARGIN 5 /* margin at top and bottom of legend graphic */
