@@ -26,7 +26,7 @@
  * DEALINGS IN THE SOFTWARE.
  ******************************************************************************
  *
- * $Log: mapmygis.c,v $
+ * $Log$
  * Revision 1.21  2006/05/26 21:46:27  tamas
  * Moving layerObj.sameconnection and msCheckConnection() internal to the MYGIS data provider.
  *
@@ -65,7 +65,7 @@
 #include <netinet/in.h>
 #endif
 
-MS_CVSID("$Id: mapmygis.c,v 1.21 2006/05/26 21:46:27 tamas Exp $")
+MS_CVSID("$Id: mapmygis.c 5464 2006-05-26 21:46:27Z tamas $")
 
 #ifndef FLT_MAX
 #define FLT_MAX 25000000.0
