@@ -27,7 +27,7 @@
  * DEALINGS IN THE SOFTWARE.
  ******************************************************************************
  *
- * $Log: mapobject.c,v $
+ * $Log$
  * Revision 1.27  2006/09/24 03:31:35  frank
  * Same as last fix, but for y dimension, instead of just x.
  *
@@ -119,7 +119,7 @@
 #  include "cpl_conv.h"
 #endif
 
-MS_CVSID("$Id: mapobject.c,v 1.27 2006/09/24 03:31:35 frank Exp $")
+MS_CVSID("$Id: mapobject.c 5762 2006-09-24 03:31:35Z frank $")
 
 void freeWeb(webObj *web);
 void freeScalebar(scalebarObj *scalebar);
