@@ -1,5 +1,5 @@
 /**********************************************************************
- * $Id: mapogr.cpp,v 1.102 2006/09/05 20:39:07 frank Exp $
+ * $Id: mapogr.cpp 5948 2007-03-03 15:09:24Z tamas $
  *
  * Name:     mapogr.cpp
  * Project:  MapServer
@@ -28,7 +28,10 @@
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
  * DEALINGS IN THE SOFTWARE.
  **********************************************************************
- * $Log: mapogr.cpp,v $
+ * $Log$
+ * Revision 1.102.2.1  2007/03/03 15:09:24  tamas
+ * Changed OGRLayerGetAutoStyle not to pass NULL pointer to GetRGBFromString causing access violation. (bug 1950)
+ *
  * Revision 1.102  2006/09/05 20:39:07  frank
  * added support for multipoint and multiline to wkt translation (bug 1618)
  *
@@ -167,7 +170,7 @@
 #  include "cpl_string.h"
 #endif
 
-MS_CVSID("$Id: mapogr.cpp,v 1.102 2006/09/05 20:39:07 frank Exp $")
+MS_CVSID("$Id: mapogr.cpp 5948 2007-03-03 15:09:24Z tamas $")
 
 #ifdef USE_OGR
 
@@ -2185,14 +2188,14 @@ static int msOGRLayerGetAutoStyle(mapObj *map, layerObj *layer, classObj *c,
               // OGR default is anchor point = LL, so label is at UR of anchor
               c->label.position = MS_UR;
 
-              if (poLabelStyle->GetRGBFromString(poLabelStyle->
-                                                 ForeColor(bIsNull),r,g,b,t))
+              const char *pszColor = poLabelStyle->ForeColor(bIsNull);
+              if (!bIsNull && poLabelStyle->GetRGBFromString(pszColor,r,g,b,t))
               {
                   MS_INIT_COLOR(c->label.color, r, g, b);
               }
-              if (poLabelStyle->GetRGBFromString(poLabelStyle->
-                                                 BackColor(bIsNull),r,g,b,t) 
-                  && !bIsNull)
+
+              pszColor = poLabelStyle->BackColor(bIsNull);
+              if (!bIsNull && poLabelStyle->GetRGBFromString(pszColor,r,g,b,t))
               {
                   MS_INIT_COLOR(c->label.color, r, g, b);
               }
@@ -2245,8 +2248,8 @@ static int msOGRLayerGetAutoStyle(mapObj *map, layerObj *layer, classObj *c,
               }
               else
               {
-                  if (poPenStyle->GetRGBFromString(poPenStyle->
-                                               Color(bIsNull),r,g,b,t))
+                  const char *pszColor = poPenStyle->Color(bIsNull);
+                  if (!bIsNull && poPenStyle->GetRGBFromString(pszColor,r,g,b,t))
                   {
                       MS_INIT_COLOR(oPenColor, r, g, b);
                       // msDebug("** PEN COLOR = %d %d %d (%d)**\n", r,g,b, nPenColor);
@@ -2310,15 +2313,15 @@ static int msOGRLayerGetAutoStyle(mapObj *map, layerObj *layer, classObj *c,
               else
               {
                   bIsBrush = TRUE;
-                  if (poBrushStyle->GetRGBFromString(poBrushStyle->
-                                                   ForeColor(bIsNull),r,g,b,t))
+                  const char *pszColor = poBrushStyle->ForeColor(bIsNull);
+                  if (!bIsNull && poBrushStyle->GetRGBFromString(pszColor,r,g,b,t))
                   {
                       MS_INIT_COLOR(c->styles[0].color, r, g, b);
                       // msDebug("** BRUSH COLOR = %d %d %d (%d)**\n", r,g,b,c->color);
                   }
-                  if (poBrushStyle->GetRGBFromString(poBrushStyle->
-                                                   BackColor(bIsNull),r,g,b,t) 
-                      && !bIsNull)
+
+                  pszColor = poBrushStyle->BackColor(bIsNull);
+                  if (!bIsNull && poBrushStyle->GetRGBFromString(pszColor,r,g,b,t))
                   {
                       MS_INIT_COLOR(c->styles[0].backgroundcolor, r, g, b);
                   }
@@ -2340,8 +2343,8 @@ static int msOGRLayerGetAutoStyle(mapObj *map, layerObj *layer, classObj *c,
           {
               OGRStyleSymbol *poSymbolStyle = (OGRStyleSymbol*)poStylePart;
 
-              if (poSymbolStyle->GetRGBFromString(poSymbolStyle->
-                                                  Color(bIsNull),r,g,b,t))
+              const char *pszColor = poSymbolStyle->Color(bIsNull);
+              if (!bIsNull && poSymbolStyle->GetRGBFromString(pszColor,r,g,b,t))
               {
                   MS_INIT_COLOR(c->styles[0].color, r, g, b);
               }
