@@ -26,7 +26,7 @@
  * DEALINGS IN THE SOFTWARE.
  ******************************************************************************
  *
- * $Log: mapoutput.c,v $
+ * $Log$
  * Revision 1.36  2006/07/11 01:09:42  frank
  * msCloneOutputFormat() needs to propagate inmapfile flag (bug 1823).
  *
@@ -145,7 +145,7 @@
 #include <assert.h>
 #include "map.h"
 
-MS_CVSID("$Id: mapoutput.c,v 1.36 2006/07/11 01:09:42 frank Exp $")
+MS_CVSID("$Id: mapoutput.c 5560 2006-07-11 01:10:34Z frank $")
 
 static outputFormatObj *msAllocOutputFormat( mapObj *map, const char *name, 
                                              const char *driver );
