@@ -26,7 +26,7 @@
  * DEALINGS IN THE SOFTWARE.
  ******************************************************************************
  *
- * $Log: mapows.c,v $
+ * $Log$
  * Revision 1.67  2006/08/23 18:28:00  dan
  * Use OWS_DEFAULT_SCHEMAS_LOCATION #define instead of hardcoded string (bug 1873)
  *
@@ -259,7 +259,7 @@
 #include <stdarg.h> 
 #include <assert.h>
 
-MS_CVSID("$Id: mapows.c,v 1.67 2006/08/23 18:28:00 dan Exp $")
+MS_CVSID("$Id: mapows.c 5639 2006-08-23 18:28:00Z dan $")
 
 /*
 ** msOWSDispatch() is the entry point for any OWS request (WMS, WFS, ...)
