@@ -27,7 +27,7 @@
  * DEALINGS IN THE SOFTWARE.
  ******************************************************************************
  *
- * $Log: mappdf.c,v $
+ * $Log$
  * Revision 1.39  2006/01/16 20:37:15  sdlime
  * Changed label size calls to not adjust baseline offset.
  *
@@ -74,7 +74,7 @@
 #endif
 #include "map.h"
 
-MS_CVSID("$Id: mappdf.c,v 1.39 2006/01/16 20:37:15 sdlime Exp $")
+MS_CVSID("$Id: mappdf.c 5110 2006-01-16 20:37:15Z sdlime $")
 
 /* -------------------------------------------------------------------- */
 /*      prototypes.                                                     */
