@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: mappool.c,v 1.14 2006/06/05 20:07:25 hobu Exp $
+ * $Id: mappool.c 5492 2006-06-05 20:07:25Z hobu $
  *
  * Project:  MapServer
  * Purpose:  Implement new style connection pooling.
@@ -27,7 +27,7 @@
  * DEALINGS IN THE SOFTWARE.
  ******************************************************************************
  *
- * $Log: mappool.c,v $
+ * $Log$
  * Revision 1.14  2006/06/05 20:07:25  hobu
  * only print debug output for unreferenced closes if debug is
  * set for the connection
@@ -178,7 +178,7 @@ o Currently the connection pooling API makes not attempt to address
 #include "map.h"
 #include "mapthread.h"
 
-MS_CVSID("$Id: mappool.c,v 1.14 2006/06/05 20:07:25 hobu Exp $")
+MS_CVSID("$Id: mappool.c 5492 2006-06-05 20:07:25Z hobu $")
 
 /* defines for lifetime.  
    A positive number is a time-from-last use in seconds */
