@@ -26,7 +26,7 @@
  * DEALINGS IN THE SOFTWARE.
  ******************************************************************************
  *
- * $Log: mappostgis.c,v $
+ * $Log$
  * Revision 1.74  2006/08/13 14:26:52  sdlime
  * Fixed typo in connection encryption addition.
  *
@@ -133,7 +133,7 @@
  *
  */
 
-/* $Id: mappostgis.c,v 1.74 2006/08/13 14:26:52 sdlime Exp $ */
+/* $Id: mappostgis.c 5585 2006-08-13 14:26:52Z sdlime $ */
 #include <assert.h>
 #include "map.h"
 #include "maptime.h"
@@ -155,7 +155,7 @@
 #include <string.h>
 #include <ctype.h> /* tolower() */
 
-MS_CVSID("$Id: mappostgis.c,v 1.74 2006/08/13 14:26:52 sdlime Exp $")
+MS_CVSID("$Id: mappostgis.c 5585 2006-08-13 14:26:52Z sdlime $")
 
 typedef struct ms_POSTGIS_layer_info_t
 {
