@@ -26,14 +26,14 @@
  * DEALINGS IN THE SOFTWARE.
  ******************************************************************************
  *
- * $Log: mappostgresql.c,v $
+ * $Log$
  * Revision 1.1  2006/05/12 18:32:41  pramsey
  * Added support for postgresql joins (Bug 1570).
  *
  */
 
 
-/* $Id: mappostgresql.c,v 1.1 2006/05/12 18:32:41 pramsey Exp $ */
+/* $Id: mappostgresql.c 5433 2006-05-12 18:32:41Z pramsey $ */
 #include <assert.h>
 #include "map.h"
 #include "maptime.h"
@@ -55,7 +55,7 @@
 #include <string.h>
 #include <ctype.h> /* tolower() */
 
-MS_CVSID("$Id: mappostgresql.c,v 1.1 2006/05/12 18:32:41 pramsey Exp $")
+MS_CVSID("$Id: mappostgresql.c 5433 2006-05-12 18:32:41Z pramsey $")
 
 
 typedef struct {
