@@ -26,7 +26,7 @@
  * DEALINGS IN THE SOFTWARE.
  ******************************************************************************
  *
- * $Log: mapprimitive.c,v $
+ * $Log$
  * Revision 1.76  2006/09/01 18:03:19  umberto
  * Removed USE_GEOS defines, bug #1890
  *
@@ -142,7 +142,7 @@
 #include "mapprimitive.h"
 #include <assert.h>
 
-MS_CVSID("$Id: mapprimitive.c,v 1.76 2006/09/01 18:03:19 umberto Exp $")
+MS_CVSID("$Id: mapprimitive.c 5724 2006-09-01 18:03:19Z umberto $")
 
 typedef enum {CLIP_LEFT, CLIP_MIDDLE, CLIP_RIGHT} CLIP_STATE;
 
