@@ -26,7 +26,7 @@
  * DEALINGS IN THE SOFTWARE.
  ******************************************************************************
  *
- * $Log: mapproject.c,v $
+ * $Log$
  * Revision 1.51  2006/02/18 21:18:02  frank
  * Avoid warning about lastPoint.
  *
@@ -84,7 +84,7 @@
 #include "mapproject.h"
 #include <assert.h>
 
-MS_CVSID("$Id: mapproject.c,v 1.51 2006/02/18 21:18:02 frank Exp $")
+MS_CVSID("$Id: mapproject.c 6088 2007-05-04 00:06:21Z warmerdam $")
 
 #ifdef USE_PROJ
 static int msTestNeedWrap( pointObj pt1, pointObj pt2, pointObj pt2_geo,
@@ -116,11 +116,21 @@ int msProjectPoint(projectionObj *in, projectionObj *out, pointObj *point)
       point->y = y_out;
   }
 
+/* -------------------------------------------------------------------- */
+/*      If the source and destination are simple and equal, then do     */
+/*      nothing.                                                        */
+/* -------------------------------------------------------------------- */
+  if( in && in->numargs == 1 && out && out->numargs == 1
+      && strcmp(in->args[0],out->args[0]) == 0 )
+  {
+      /* do nothing, no transformation required */
+  }
+
 /* -------------------------------------------------------------------- */
 /*      If we have a fully defined input coordinate system and          */
 /*      output coordinate system, then we will use pj_transform.        */
 /* -------------------------------------------------------------------- */
-  if( in && in->proj && out && out->proj )
+  else if( in && in->proj && out && out->proj )
   {
       double	z = 0.0;
 
