@@ -26,7 +26,7 @@
  * DEALINGS IN THE SOFTWARE.
  ******************************************************************************
  *
- * $Log: mapquery.c,v $
+ * $Log$
  * Revision 1.91  2006/02/02 01:00:11  sdlime
  * Moved the code to free previous query results a bit higher in the msQueryByAttribute() function.
  *
@@ -61,7 +61,7 @@
 
 #include "map.h"
 
-MS_CVSID("$Id: mapquery.c,v 1.91 2006/02/02 01:00:11 sdlime Exp $")
+MS_CVSID("$Id: mapquery.c 5158 2006-02-02 01:00:11Z sdlime $")
 
 /*
 ** msIsLayerQueryable()  returns MS_TRUE/MS_FALSE
