@@ -28,7 +28,7 @@
  * DEALINGS IN THE SOFTWARE.
  ******************************************************************************
  *
- * $Log: mapraster.c,v $
+ * $Log$
  * Revision 1.137  2006/09/24 02:42:12  frank
  * handle upsidedown images through resample logic. (bug 1904)
  *
@@ -120,7 +120,7 @@
 #include "mapresample.h"
 #include "mapthread.h"
 
-MS_CVSID("$Id: mapraster.c,v 1.137 2006/09/24 02:42:12 frank Exp $")
+MS_CVSID("$Id: mapraster.c 5761 2006-09-24 02:42:12Z frank $")
 
 extern int msyyparse(void);
 extern int msyylex(void);
