@@ -26,7 +26,7 @@
  * DEALINGS IN THE SOFTWARE.
  ******************************************************************************
  *
- * $Log: maprasterquery.c,v $
+ * $Log$
  * Revision 1.23  2006/06/23 20:39:19  frank
  * fix time filter propogation to tileindex layer
  *
@@ -110,7 +110,7 @@
 #include "mapresample.h"
 #include "mapthread.h"
 
-MS_CVSID("$Id: maprasterquery.c,v 1.23 2006/06/23 20:39:19 frank Exp $")
+MS_CVSID("$Id: maprasterquery.c 5514 2006-06-23 20:39:19Z frank $")
 
 int msRASTERLayerGetShape(layerObj *layer, shapeObj *shape, int tile, 
                           long record);
