@@ -26,7 +26,7 @@
  * DEALINGS IN THE SOFTWARE.
  ******************************************************************************
  *
- * $Log: mapresample.c,v $
+ * $Log$
  * Revision 1.67  2006/03/15 20:31:18  frank
  * Fixup comment for last change.
  *
@@ -134,7 +134,7 @@
 #include <assert.h>
 #include "mapresample.h"
 
-MS_CVSID("$Id: mapresample.c,v 1.67 2006/03/15 20:31:18 frank Exp $")
+MS_CVSID("$Id: mapresample.c 5273 2006-03-15 20:32:49Z frank $")
 
 #ifndef MAX
 #  define MIN(a,b)      ((a<b) ? a : b)
