@@ -26,7 +26,7 @@
  * DEALINGS IN THE SOFTWARE.
  ******************************************************************************
  *
- * $Log: mapscale.c,v $
+ * $Log$
  * Revision 1.52  2006/08/26 22:04:13  novak
  * Enable support for TrueType fonts (bug 1882)
  *
@@ -58,7 +58,7 @@
 
 #include "map.h"
 
-MS_CVSID("$Id: mapscale.c,v 1.52 2006/08/26 22:04:13 novak Exp $")
+MS_CVSID("$Id: mapscale.c 5677 2006-08-26 22:04:13Z novak $")
 
 #define VMARGIN 3 /* buffer around the scalebar */
 #define HMARGIN 3
