@@ -1,4 +1,4 @@
-# $Id: setup.py,v 1.19 2006/05/31 14:48:31 hobu Exp $
+# $Id: setup.py 5915 2007-02-19 15:13:45Z hobu $
 #
 # setup.py file for MapScript
 #
@@ -57,16 +57,25 @@ lib_dirs = lib_dirs + string.split(ms_install_dir)
 
 libs = []
 extras = []
+ex_next = False
 
 for x in lib_opts:
-    if x[:2] == '-l':
+    if ex_next:
+        extras.append(x)
+        ex_next = False
+    elif x[:2] == '-l':
         libs.append( x[2:] )
-    if x[-4:] == '.lib' or x[-4:] == '.LIB':
+    elif x[-4:] == '.lib' or x[-4:] == '.LIB':
 	    dir, lib = os.path.split(x)
 	    libs.append( lib[:-4] )
 	    if len(dir) > 0:
 	        lib_dirs.append( dir )
-    if x[-2:] == '.a':
+    elif x[-2:] == '.a':
+        extras.append(x)
+    elif x[:10] == '-framework':
+        extras.append(x)
+        ex_next = True
+    elif x[:2] == '-F':
         extras.append(x)
         
 libs = unique(libs)
