@@ -26,7 +26,7 @@
  * DEALINGS IN THE SOFTWARE.
  ******************************************************************************
  *
- * $Log: mapsearch.c,v $
+ * $Log$
  * Revision 1.17  2005/06/14 16:03:34  dan
  * Updated copyright date to 2005
  *
@@ -40,7 +40,7 @@
 
 #include "map.h"
 
-MS_CVSID("$Id: mapsearch.c,v 1.17 2005/06/14 16:03:34 dan Exp $")
+MS_CVSID("$Id: mapsearch.c 4695 2005-06-14 16:03:36Z dan $")
 
 #define LASTVERT(v,n)  ((v) == 0 ? n-2 : v-1)
 #define NEXTVERT(v,n)  ((v) == n-2 ? 0 : v+1)
