@@ -31,7 +31,7 @@
  * DEALINGS IN THE SOFTWARE.
  ******************************************************************************
  *
- * $Log: mapshape.c,v $
+ * $Log$
  * Revision 1.73  2006/07/12 06:17:17  sdlime
  * Added debug statements to output information when tiles tiles are not found (mimicing mapraster.c). Useful when debuging tileindex problems.
  *
@@ -74,7 +74,7 @@
 #include <assert.h>
 #include "map.h"
 
-MS_CVSID("$Id: mapshape.c,v 1.73 2006/07/12 06:17:17 sdlime Exp $")
+MS_CVSID("$Id: mapshape.c 5561 2006-07-12 06:17:17Z sdlime $")
 
 
 #define ByteCopy( a, b, c )     memcpy( b, a, c )
