@@ -27,7 +27,7 @@
  * DEALINGS IN THE SOFTWARE.
  ******************************************************************************
  *
- * $Log: mapstring.c,v $
+ * $Log$
  * Revision 1.35  2006/08/16 14:05:07  sdlime
  * Removed any ambiguity with msCommifyString(). At the moment it only handles North American representaions of numbers (e.g. 2,345.678).
  *
@@ -59,7 +59,7 @@
 
 #include "map.h"
 
-MS_CVSID("$Id: mapstring.c,v 1.35 2006/08/16 14:05:07 sdlime Exp $")
+MS_CVSID("$Id: mapstring.c 5599 2006-08-16 14:05:07Z sdlime $")
 
 #include <ctype.h>
 
