@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: mapsvg.c,v 1.22 2006/01/16 20:21:18 sdlime Exp $
+ * $Id: mapsvg.c 6084 2007-05-03 16:05:17Z Assefa $
  *
  * Name:     mapsvg.c
  * Project:  MapServer
@@ -30,7 +30,7 @@
  * DEALINGS IN THE SOFTWARE.
  ******************************************************************************
  *
- * $Log: mapsvg.c,v $
+ * $Log$
  * Revision 1.22  2006/01/16 20:21:18  sdlime
  * Fixed error with image legends (shifted text) introduced by the 1449 bug fix. (bug 1607)
  *
@@ -111,7 +111,7 @@
 #endif
 #include "map.h"
 
-MS_CVSID("$Id: mapsvg.c,v 1.22 2006/01/16 20:21:18 sdlime Exp $")
+MS_CVSID("$Id: mapsvg.c 6084 2007-05-03 16:05:17Z Assefa $")
 
 
 static int msIO_fprintfgz(FILE *fp, int bCompressed, const char *format, ... )
@@ -725,7 +725,7 @@ static void imageFillPolygon(FILE *fp, int bCompressed,
                            psOutlineColor->red, psOutlineColor->green, 
                            psOutlineColor->blue,
                            size, pszDashArray);*/
-                msIO_fprintfgz(fp,  bCompressed, "<path stroke=\"#%02x%02x%02x\" stroke-width=\"%d\"%s d=\"",
+                msIO_fprintfgz(fp,  bCompressed, "<path stroke=\"#%02x%02x%02x\" stroke-width=\"%d\"%s style=\"fill:none\" d=\"",
                            psOutlineColor->red, psOutlineColor->green, 
                            psOutlineColor->blue,
                            size, pszDashArray);
