@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: mapthread.c,v 1.16 2006/02/18 16:00:54 hobu Exp $
+ * $Id: mapthread.c 5209 2006-02-18 16:00:54Z hobu $
  *
  * Project:  UMN MapServer
  * Purpose:  Support code for abstracting thread issues.
@@ -27,7 +27,7 @@
  * DEALINGS IN THE SOFTWARE.
  ******************************************************************************
  *
- * $Log: mapthread.c,v $
+ * $Log$
  * Revision 1.16  2006/02/18 16:00:54  hobu
  * Fix for mapthread.c to check for the non-existence of _WIN32 rather
  * than unix to use posix threads (bug 1672).
@@ -190,7 +190,7 @@ files instead.
 #include "map.h"
 #include "mapthread.h"
 
-MS_CVSID("$Id: mapthread.c,v 1.16 2006/02/18 16:00:54 hobu Exp $")
+MS_CVSID("$Id: mapthread.c 5209 2006-02-18 16:00:54Z hobu $")
 
 #if defined(USE_THREAD)
 static int thread_debug = 0;
