@@ -26,7 +26,7 @@
  * DEALINGS IN THE SOFTWARE.
  ******************************************************************************
  *
- * $Log: maptime.c,v $
+ * $Log$
  * Revision 1.19  2006/03/14 03:43:30  assefa
  * Move msValidateTimeValue to maptime so it can be used by WMS and SOS.
  * (Bug 1710)
@@ -59,7 +59,7 @@
 #include "maptime.h"
 #include "maperror.h"
 
-MS_CVSID("$Id: maptime.c,v 1.19 2006/03/14 03:43:30 assefa Exp $")
+MS_CVSID("$Id: maptime.c 5258 2006-03-14 03:43:30Z assefa $")
 
 typedef struct {
   char pattern[64];
