@@ -27,7 +27,7 @@
  * DEALINGS IN THE SOFTWARE.
  ******************************************************************************
  *
- * $Log: maptree.c,v $
+ * $Log$
  * Revision 1.18  2006/04/19 16:36:18  hobu
  * don't throw an MS_IOERR when we're in debug mode when we don't find an index (bug 1752)
  *
@@ -48,7 +48,7 @@
 #include "map.h"
 #include "maptree.h"
 
-MS_CVSID("$Id: maptree.c,v 1.18 2006/04/19 16:36:18 hobu Exp $")
+MS_CVSID("$Id: maptree.c 5397 2006-04-19 16:36:18Z hobu $")
 
 /* -------------------------------------------------------------------- */
 /*      If the following is 0.5, nodes will be split in half.  If it    */
