@@ -26,7 +26,7 @@
  * DEALINGS IN THE SOFTWARE.
  ******************************************************************************
  *
- * $Log: maputil.c,v $
+ * $Log$
  * Revision 1.190  2006/08/15 17:24:56  dan
  * Fixed problem with PHP MapScript's saveWebImage() filename collisions
  * when mapscript was loaded in php.ini with PHP as an Apache DSO (bug 1322)
@@ -142,7 +142,7 @@
 #include <process.h>
 #endif
 
-MS_CVSID("$Id: maputil.c,v 1.190 2006/08/15 17:24:56 dan Exp $")
+MS_CVSID("$Id: maputil.c 5597 2006-08-15 17:24:56Z dan $")
 
 extern int msyyparse(void);
 extern int msyylex(void);
