@@ -26,7 +26,10 @@
  * DEALINGS IN THE SOFTWARE.
  ******************************************************************************
  *
- * $Log: mapwcs.c,v $
+ * $Log$
+ * Revision 1.71.4.1  2007/01/19 03:46:45  sdlime
+ * Fixed requestResponseCRSs output to create multiple tags instead of one with a space delimited list. (bug 1148)
+ *
  * Revision 1.71  2005/09/23 04:37:32  frank
  * added preliminary WCS INTERPOLATION support
  *
@@ -98,7 +101,7 @@
 #include "maperror.h"
 #include "mapthread.h"
 
-MS_CVSID("$Id: mapwcs.c,v 1.71 2005/09/23 04:37:32 frank Exp $")
+MS_CVSID("$Id: mapwcs.c 6405 2007-07-27 17:33:25Z warmerdam $")
 
 #ifdef USE_WCS_SVR
 
@@ -816,9 +819,11 @@ static int msWCSDescribeCoverage_AxisDescription(layerObj *layer, char *name)
 
 static int msWCSDescribeCoverage_CoverageOffering(layerObj *layer, wcsParamsObj *params) 
 {
+  char **tokens;
+  int numtokens;
   const char *value; 
   coverageMetadataObj cm;
-  int status;
+  int i, status;
 
   if(!msWCSIsLayerSupported(layer)) return MS_SUCCESS; /* not an error, this layer cannot be served via WCS */
 
@@ -903,7 +908,6 @@ static int msWCSDescribeCoverage_CoverageOffering(layerObj *layer, wcsParamsObj
 
     /* TimePosition (should support a value AUTO, then we could mine positions from the timeitem) */
     msOWSPrintEncodeMetadataList(stdout, &(layer->metadata), "COM", "timeposition", NULL, NULL, "        <gml:timePosition>%s</gml:timePosition>\n", NULL);    
-
     /* TODO:  add TimePeriod (only one per layer)  */
 
     msIO_printf("      </temporalDomain>\n");
@@ -924,15 +928,12 @@ static int msWCSDescribeCoverage_CoverageOffering(layerObj *layer, wcsParamsObj
   
   /* compound range sets */
   if((value = msOWSLookupMetadata(&(layer->metadata), "COM", "rangeset_axes")) != NULL) {
-    char **tokens;
-    int numtokens;
-
-     tokens = split(value, ',', &numtokens);
-     if(tokens && numtokens > 0) {
-       int i;
-       for(i=0; i<numtokens; i++)
-         msWCSDescribeCoverage_AxisDescription(layer, tokens[i]);
-     }
+    tokens = split(value, ',', &numtokens);
+    if(tokens && numtokens > 0) {
+      for(i=0; i<numtokens; i++)
+       msWCSDescribeCoverage_AxisDescription(layer, tokens[i]);
+      msFreeCharArray(tokens, numtokens);
+    }
   }
   
   msIO_printf("      </RangeSet>\n");
@@ -942,11 +943,21 @@ static int msWCSDescribeCoverage_CoverageOffering(layerObj *layer, wcsParamsObj
   msIO_printf("    <supportedCRSs>\n");
   
   /* requestResposeCRSs: check the layer metadata/projection, and then the map metadata/projection if necessary (should never get to the error message) */
-  if((value = msOWSGetEPSGProj(&(layer->projection), &(layer->metadata), "COM", MS_FALSE)) != NULL)    
-    msIO_printf("      <requestResponseCRSs>%s</requestResponseCRSs>\n", value);
-  else if((value = msOWSGetEPSGProj(&(layer->map->projection), &(layer->map->web.metadata), "COM", MS_FALSE)) != NULL)
-    msIO_printf("      <requestResponseCRSs>%s</requestResponseCRSs>\n", value);
-  else 
+  if((value = msOWSGetEPSGProj(&(layer->projection), &(layer->metadata), "COM", MS_FALSE)) != NULL) {
+    tokens = split(value, ' ', &numtokens);
+    if(tokens && numtokens > 0) {
+      for(i=0; i<numtokens; i++)
+        msIO_printf("      <requestResponseCRSs>%s</requestResponseCRSs>\n", tokens[i]);
+      msFreeCharArray(tokens, numtokens);
+    }
+  } else if((value = msOWSGetEPSGProj(&(layer->map->projection), &(layer->map->web.metadata), "COM", MS_FALSE)) != NULL) {
+    tokens = split(value, ' ', &numtokens);
+    if(tokens && numtokens > 0) {
+      for(i=0; i<numtokens; i++)
+        msIO_printf("      <requestResponseCRSs>%s</requestResponseCRSs>\n", tokens[i]);
+      msFreeCharArray(tokens, numtokens);
+    }
+  } else 
     msIO_printf("      <!-- requestResponseCRSs ERROR: missing required information, no SRSs defined -->\n");
   
   /* nativeCRSs (only one in our case) */
@@ -1265,6 +1276,11 @@ static int msWCSGetCoverage(mapObj *map, cgiRequestObj *request,
   map->cellsize = params->resx; /* pick one, MapServer only supports square cells (what about msAdjustExtent here!) */
 
   msMapComputeGeotransform(map);
+
+  /* Do we need to fake out stuff for rotated support? */ 
+  if( map->gt.need_geotransform ) 
+      msMapSetFakedExtent( map ); 
+
   map->projection.gt = map->gt;
 
   /* check and make sure there is a format, and that it's valid (TODO: make sure in the layer metadata) */
