@@ -1,5 +1,5 @@
 /**********************************************************************
- * $Id: mapwfs.c,v 1.87 2006/09/06 17:26:24 sdlime Exp $
+ * $Id: mapwfs.c 5749 2006-09-06 17:26:24Z sdlime $
  *
  * Name:     mapwfs.c
  * Project:  MapServer
@@ -28,7 +28,7 @@
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
  * DEALINGS IN THE SOFTWARE.
  **********************************************************************
- * $Log: mapwfs.c,v $
+ * $Log$
  * Revision 1.87  2006/09/06 17:26:24  sdlime
  * Removed advertising GML3 support in WFS 1.0.0 getCapabilities output.
  *
@@ -120,7 +120,7 @@
 
 #include "map.h"
 
-MS_CVSID("$Id: mapwfs.c,v 1.87 2006/09/06 17:26:24 sdlime Exp $")
+MS_CVSID("$Id: mapwfs.c 5749 2006-09-06 17:26:24Z sdlime $")
 
 #if defined(USE_WFS_SVR)
 
