@@ -26,7 +26,7 @@
  * DEALINGS IN THE SOFTWARE.
  **********************************************************************
  *
- * $Log: mapwfslayer.c,v $
+ * $Log$
  * Revision 1.37  2006/05/19 20:53:27  dan
  * Use lp->layerinfo for OGR connections (instead of ogrlayerinfo) (bug 331)
  *
@@ -157,7 +157,7 @@
 #include <process.h>
 #endif
 
-MS_CVSID("$Id: mapwfslayer.c,v 1.37 2006/05/19 20:53:27 dan Exp $")
+MS_CVSID("$Id: mapwfslayer.c 5445 2006-05-19 20:53:27Z dan $")
 
 #define WFS_V_0_0_14  14
 #define WFS_V_1_0_0  100
