@@ -28,7 +28,7 @@
  * DEALINGS IN THE SOFTWARE.
  ******************************************************************************
  *
- * $Log: mapxbase.c,v $
+ * $Log$
  * Revision 1.23  2006/08/22 13:54:37  hobu
  * cast the second argument to char* that we're passing into strncopy
  *
@@ -53,7 +53,7 @@
 #include <stdlib.h> /* for atof() and atoi() */
 #include <math.h>
 
-MS_CVSID("$Id: mapxbase.c,v 1.23 2006/08/22 13:54:37 hobu Exp $")
+MS_CVSID("$Id: mapxbase.c 5620 2006-08-22 13:54:37Z hobu $")
 
 /************************************************************************/
 /*                             SfRealloc()                              */
