@@ -26,7 +26,7 @@
  * DEALINGS IN THE SOFTWARE.
  ******************************************************************************
  *
- * $Log: msencrypt.c,v $
+ * $Log$
  * Revision 1.2  2006/06/02 18:56:24  dan
  * Fixed buffer overflow when encrypting string (buffer passed to
  * msEncryptStringWithKey() didn't include enough room for padding)
@@ -39,7 +39,7 @@
 
 #include "map.h"
 
-MS_CVSID("$Id: msencrypt.c,v 1.2 2006/06/02 18:56:24 dan Exp $")
+MS_CVSID("$Id: msencrypt.c 5481 2006-06-02 18:56:24Z dan $")
 
 void PrintUsage()
 {
