@@ -26,7 +26,7 @@
  * DEALINGS IN THE SOFTWARE.
  ******************************************************************************
  *
- * $Log: scalebar.c,v $
+ * $Log$
  * Revision 1.11  2005/06/14 16:03:35  dan
  * Updated copyright date to 2005
  *
@@ -37,7 +37,7 @@
 
 #include "map.h"
 
-MS_CVSID("$Id: scalebar.c,v 1.11 2005/06/14 16:03:35 dan Exp $")
+MS_CVSID("$Id: scalebar.c 4695 2005-06-14 16:03:36Z dan $")
 
 int main(int argc, char *argv[])
 {
