@@ -26,7 +26,7 @@
  * DEALINGS IN THE SOFTWARE.
  ******************************************************************************
  *
- * $Log: shp2img.c,v $
+ * $Log$
  * Revision 1.20  2006/05/12 20:59:07  frank
  * Removed -t switch, it doesn't work.
  *
@@ -59,7 +59,7 @@
 
 #include "map.h"
 
-MS_CVSID("$Id: shp2img.c,v 1.20 2006/05/12 20:59:07 frank Exp $")
+MS_CVSID("$Id: shp2img.c 5434 2006-05-12 20:59:07Z frank $")
 
 int main(int argc, char *argv[])
 {
