@@ -26,7 +26,7 @@
  * DEALINGS IN THE SOFTWARE.
  ******************************************************************************
  *
- * $Log: shp2pdf.c,v $
+ * $Log$
  * Revision 1.7  2005/06/14 16:03:35  dan
  * Updated copyright date to 2005
  *
@@ -43,7 +43,7 @@
 
 #include "map.h"
 
-MS_CVSID("$Id: shp2pdf.c,v 1.7 2005/06/14 16:03:35 dan Exp $")
+MS_CVSID("$Id: shp2pdf.c 4695 2005-06-14 16:03:36Z dan $")
 
 #ifdef USE_PDF
 #include <pdflib.h>
