@@ -26,7 +26,7 @@
  * DEALINGS IN THE SOFTWARE.
  ******************************************************************************
  *
- * $Log: shptree.c,v $
+ * $Log$
  * Revision 1.11  2005/06/14 16:03:35  dan
  * Updated copyright date to 2005
  *
@@ -39,7 +39,7 @@
 #include "maptree.h"
 #include <string.h>
 
-MS_CVSID("$Id: shptree.c,v 1.11 2005/06/14 16:03:35 dan Exp $")
+MS_CVSID("$Id: shptree.c 4695 2005-06-14 16:03:36Z dan $")
 
 char* AddFileSuffix ( const char * Filename, const char * Suffix ) {
   char	*pszFullname, *pszBasename;
