@@ -26,7 +26,7 @@
  * DEALINGS IN THE SOFTWARE.
  ******************************************************************************
  *
- * $Log: shptreetst.c,v $
+ * $Log$
  * Revision 1.8  2005/06/14 16:03:35  dan
  * Updated copyright date to 2005
  *
@@ -40,7 +40,7 @@
 #include <unistd.h>
 #include <stdlib.h>
 
-MS_CVSID("$Id: shptreetst.c,v 1.8 2005/06/14 16:03:35 dan Exp $")
+MS_CVSID("$Id: shptreetst.c 4695 2005-06-14 16:03:36Z dan $")
 
 #ifdef SHPT_POLYGON
    #undef MAPSERVER
