@@ -26,7 +26,7 @@
  * DEALINGS IN THE SOFTWARE.
  ******************************************************************************
  *
- * $Log: shptreevis.c,v $
+ * $Log$
  * Revision 1.14  2005/06/14 16:03:35  dan
  * Updated copyright date to 2005
  *
@@ -47,7 +47,7 @@
 #endif
 #include <stdlib.h>
 
-MS_CVSID("$Id: shptreevis.c,v 1.14 2005/06/14 16:03:35 dan Exp $")
+MS_CVSID("$Id: shptreevis.c 4695 2005-06-14 16:03:36Z dan $")
 
 #ifdef SHPT_POLYGON
    #undef MAPSERVER
