@@ -26,7 +26,7 @@
  * DEALINGS IN THE SOFTWARE.
  ******************************************************************************
  *
- * $Log: sym2img.c,v $
+ * $Log$
  * Revision 1.9  2005/06/14 16:03:35  dan
  * Updated copyright date to 2005
  *
@@ -43,7 +43,7 @@
 
 #include "map.h"
 
-MS_CVSID("$Id: sym2img.c,v 1.9 2005/06/14 16:03:35 dan Exp $")
+MS_CVSID("$Id: sym2img.c 4695 2005-06-14 16:03:36Z dan $")
 
 #define MAXCOLORS 256
 #define CELLSIZE 100
