@@ -26,7 +26,7 @@
  * DEALINGS IN THE SOFTWARE.
  ******************************************************************************
  *
- * $Log: testexpr.c,v $
+ * $Log$
  * Revision 1.6  2005/06/14 16:03:35  dan
  * Updated copyright date to 2005
  *
@@ -43,7 +43,7 @@
 #include "map.h"
 #include "mapparser.h"
 
-MS_CVSID("$Id: testexpr.c,v 1.6 2005/06/14 16:03:35 dan Exp $")
+MS_CVSID("$Id: testexpr.c 4695 2005-06-14 16:03:36Z dan $")
 
 extern int msyyparse();
 extern int msyylex();
